function h=kdint2(A,x,y,z)

% KDINT2      Calculate kde height using linear interpolation.
%
%             Example: load kddata
%                      [x,y,z]=kdfft2(mask4,'knorm',64,0);
%                      h=kdint2(mask4,x,y,z);
%
%             KDINT2(A,X,Y,Z)
%
%             Christian C. Beardah 1995 

z=z';

[n,d]=size(A);

deltax=x(2)-x(1);
deltay=y(2)-y(1);

binx=ceil((A(:,1)-x(1))/deltax);
biny=ceil((A(:,2)-y(1))/deltay);

w=deltax*deltay;

for i=1:n,
  w11(i,1)=(x(binx(i)+1)-A(i,1))*(y(biny(i)+1)-A(i,2));
  w12(i,1)=(A(i,1)-x(binx(i)))*(y(biny(i)+1)-A(i,2));  
  w21(i,1)=(x(binx(i)+1)-A(i,1))*(A(i,2)-y(biny(i)));
  w22(i,1)=(A(i,1)-x(binx(i)))*(A(i,2)-y(biny(i)));  

  h(i,1)=(w11(i,1)*z(binx(i),biny(i))+w12(i,1)*z(binx(i)+1,biny(i))+...
          w21(i,1)*z(binx(i),biny(i)+1)+w22(i,1)*z(binx(i)+1,biny(i)+1))/w;

end;
