function pclvl3b(p,A,X,Y,Z,dgrid,ddata)

% PCLVL3B     Kernel Density estimate p% contour plot for tri-variate data.
%
%             Example: 
%
%             PCLVL3B(P,A,X,Y,Z,DGRID,DDATA) displays a surface which encloses P% 
%             of the data.  Groups are formed by ranking the data by 
%             kernel density estimate.
%
%             The rows of A contain the whole data-set.
% 
%             The kernel is given by the function in K.
%             'KMVN' is the multivariate normal distribution.
%
%             INC controls the granularity of the mesh.
%
%             The optional parameter H represents the window width.
%             If omitted, an 'optimal' value is used.
%
%             Christian C. Beardah 1996

n=length(ddata);

x=A(:,1);
y=A(:,2);
z=A(:,3);

w=zeros(length(p),2);

p=100-p;
p=sort(p);
p=p(length(p):-1:1);

[order index]=sort(ddata);

m=ceil(n*p/100);

col=['wbwbwb'];

for i=1:length(p),
  if m(i)==0,
    v(i)=0.9*order(1); 
  end;

  if m(i)>0 & m(i)<n,
    v(i)=(order(m(i))+order(m(i)+1))/2;
  end;

  if m(i)==n,
    v(i)=(order(n-1)+order(n))/2;
  end;

  dtest=(abs(dgrid-v(i))<(v(i)/10));

  Zd=(Z.*dtest)+(NaN*(~dtest));

  surf(X,Y,Zd);

  pause;

  [ip,jp]=find(dtest);
  for k=1:length(ip),
    hpt(k,:)=[X(ip(k),jp(k)) Y(ip(k),jp(k)) Z(ip(k),jp(k))];
  end;

  [hpt(1:length(ip),1) xind]=sort(hpt(1:length(ip),1));

  plot3(hpt(1:length(ip),1),hpt(xind,2),hpt(xind,3),[col(i),'-']);
  if i==1,
    hold on;
  end;

end;

hpt

xlabel('x values');
ylabel('y values');
zlabel('z values');

hold off;